@@ -1,17 +1,27 @@
 """Certbot client interfaces."""
-import abc
+from abc import ABCMeta
+from abc import abstractmethod
+from argparse import ArgumentParser
+import sys
+from types import ModuleType
+from typing import cast
+from typing import Iterable
+from typing import List
+from typing import Optional
+import warnings
 
-import six
 import zope.interface
 
-# pylint: disable=no-self-argument,no-method-argument,inherit-non-class
+from acme.challenges import Challenge
+from acme.challenges import ChallengeResponse
+from certbot.achallenges import AnnotatedChallenge
+from certbot import configuration
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AccountStorage(object):
+class AccountStorage(metaclass=ABCMeta):
     """Accounts storage interface."""
 
-    @abc.abstractmethod
+    @abstractmethod
     def find_all(self):  # pragma: no cover
         """Find all accounts.
 
@@ -21,7 +31,7 @@ class AccountStorage(object):
         """
         raise NotImplementedError()
 
-    @abc.abstractmethod
+    @abstractmethod
     def load(self, account_id):  # pragma: no cover
         """Load an account by its id.
 
@@ -31,7 +41,7 @@ class AccountStorage(object):
         """
         raise NotImplementedError()
 
-    @abc.abstractmethod
+    @abstractmethod
     def save(self, account, client):  # pragma: no cover
         """Save account.
 
@@ -41,8 +51,20 @@ class AccountStorage(object):
         raise NotImplementedError()
 
 
-class IPluginFactory(zope.interface.Interface):
-    """IPlugin factory.
+class IConfig(zope.interface.Interface):  # pylint: disable=inherit-non-class
+    """Deprecated, use certbot.configuration.NamespaceConfig instead."""
+
+
+class IPluginFactory(zope.interface.Interface):  # pylint: disable=inherit-non-class
+    """Deprecated, use certbot.interfaces.Plugin as ABC instead."""
+
+
+class IPlugin(zope.interface.Interface):  # pylint: disable=inherit-non-class
+    """Deprecated, use certbot.interfaces.Plugin as ABC instead."""
+
+
+class Plugin(metaclass=ABCMeta):
+    """Certbot plugin.
 
     Objects providing this interface will be called without satisfying
     any entry point "extras" (extra dependencies) you might have defined
@@ -71,35 +93,21 @@ class IPluginFactory(zope.interface.Interface):
 
     """
 
-    description = zope.interface.Attribute("Short plugin description")
+    description: str = NotImplemented
+    """Short plugin description"""
 
-    def __call__(config, name):  # pylint: disable=signature-differs
-        """Create new `IPlugin`.
+    @abstractmethod
+    def __init__(self, config: configuration.NamespaceConfig, name: str):
+        """Create a new `Plugin`.
 
-        :param IConfig config: Configuration.
+        :param configuration.NamespaceConfig config: Configuration.
         :param str name: Unique plugin name.
 
         """
+        super().__init__()
 
-    def inject_parser_options(parser, name):
-        """Inject argument parser options (flags).
-
-        1. Be nice and prepend all options and destinations with
-        `~.common.option_namespace` and `~common.dest_namespace`.
-
-        2. Inject options (flags) only. Positional arguments are not
-        allowed, as this would break the CLI.
-
-        :param ArgumentParser parser: (Almost) top-level CLI parser.
-        :param str name: Unique plugin name.
-
-        """
-
-
-class IPlugin(zope.interface.Interface):
-    """Certbot plugin."""
-
-    def prepare():  # type: ignore
+    @abstractmethod
+    def prepare(self) -> None:
         """Prepare the plugin.
 
         Finish up any additional initialization.
@@ -118,7 +126,8 @@ class IPlugin(zope.interface.Interface):
 
         """
 
-    def more_info():  # type: ignore
+    @abstractmethod
+    def more_info(self) -> str:
         """Human-readable string to help the user.
 
         Should describe the steps taken and any relevant info to help the user
@@ -128,8 +137,28 @@ class IPlugin(zope.interface.Interface):
 
         """
 
+    @classmethod
+    @abstractmethod
+    def inject_parser_options(cls, parser: ArgumentParser, name: str) -> None:
+        """Inject argument parser options (flags).
 
-class IAuthenticator(IPlugin):
+        1. Be nice and prepend all options and destinations with
+        `~.common.option_namespace` and `~common.dest_namespace`.
+
+        2. Inject options (flags) only. Positional arguments are not
+        allowed, as this would break the CLI.
+
+        :param ArgumentParser parser: (Almost) top-level CLI parser.
+        :param str name: Unique plugin name.
+
+        """
+
+
+class IAuthenticator(IPlugin):  # pylint: disable=inherit-non-class
+    """Deprecated, use certbot.interfaces.Authenticator as ABC instead."""
+
+
+class Authenticator(Plugin):
     """Generic Certbot Authenticator.
 
     Class represents all possible tools processes that have the
@@ -137,7 +166,8 @@ class IAuthenticator(IPlugin):
 
     """
 
-    def get_chall_pref(domain):
+    @abstractmethod
+    def get_chall_pref(self, domain: str) -> Iterable[Challenge]:
         """Return `collections.Iterable` of challenge preferences.
 
         :param str domain: Domain for which challenge preferences are sought.
@@ -150,7 +180,8 @@ class IAuthenticator(IPlugin):
 
         """
 
-    def perform(achalls):
+    @abstractmethod
+    def perform(self, achalls: List[AnnotatedChallenge]) -> Iterable[ChallengeResponse]:
         """Perform the given challenge.
 
         :param list achalls: Non-empty (guaranteed) list of
@@ -170,7 +201,8 @@ class IAuthenticator(IPlugin):
 
         """
 
-    def cleanup(achalls):
+    @abstractmethod
+    def cleanup(self, achalls: List[AnnotatedChallenge]) -> None:
         """Revert changes and shutdown after challenges complete.
 
         This method should be able to revert all changes made by
@@ -185,90 +217,11 @@ class IAuthenticator(IPlugin):
         """
 
 
-class IConfig(zope.interface.Interface):
-    """Certbot user-supplied configuration.
-
-    .. warning:: The values stored in the configuration have not been
-        filtered, stripped or sanitized.
-
-    """
-    server = zope.interface.Attribute("ACME Directory Resource URI.")
-    email = zope.interface.Attribute(
-        "Email used for registration and recovery contact. Use comma to "
-        "register multiple emails, ex: u1@example.com,u2@example.com. "
-        "(default: Ask).")
-    rsa_key_size = zope.interface.Attribute("Size of the RSA key.")
-    elliptic_curve = zope.interface.Attribute(
-        "The SECG elliptic curve name to use. Please see RFC 8446 "
-        "for supported values."
-    )
-    key_type = zope.interface.Attribute(
-        "Type of generated private key"
-        "(Only *ONE* per invocation can be provided at this time)")
-    must_staple = zope.interface.Attribute(
-        "Adds the OCSP Must Staple extension to the certificate. "
-        "Autoconfigures OCSP Stapling for supported setups "
-        "(Apache version >= 2.3.3 ).")
-
-    config_dir = zope.interface.Attribute("Configuration directory.")
-    work_dir = zope.interface.Attribute("Working directory.")
-
-    accounts_dir = zope.interface.Attribute(
-        "Directory where all account information is stored.")
-    backup_dir = zope.interface.Attribute("Configuration backups directory.")
-    csr_dir = zope.interface.Attribute(
-        "Directory where newly generated Certificate Signing Requests "
-        "(CSRs) are saved.")
-    in_progress_dir = zope.interface.Attribute(
-        "Directory used before a permanent checkpoint is finalized.")
-    key_dir = zope.interface.Attribute("Keys storage.")
-    temp_checkpoint_dir = zope.interface.Attribute(
-        "Temporary checkpoint directory.")
-
-    no_verify_ssl = zope.interface.Attribute(
-        "Disable verification of the ACME server's certificate.")
-
-    http01_port = zope.interface.Attribute(
-        "Port used in the http-01 challenge. "
-        "This only affects the port Certbot listens on. "
-        "A conforming ACME server will still attempt to connect on port 80.")
-
-    http01_address = zope.interface.Attribute(
-        "The address the server listens to during http-01 challenge.")
-
-    https_port = zope.interface.Attribute(
-        "Port used to serve HTTPS. "
-        "This affects which port Nginx will listen on after a LE certificate "
-        "is installed.")
-
-    pref_challs = zope.interface.Attribute(
-        "Sorted user specified preferred challenges"
-        "type strings with the most preferred challenge listed first")
-
-    allow_subset_of_names = zope.interface.Attribute(
-        "When performing domain validation, do not consider it a failure "
-        "if authorizations can not be obtained for a strict subset of "
-        "the requested domains. This may be useful for allowing renewals for "
-        "multiple domains to succeed even if some domains no longer point "
-        "at this system. This is a boolean")
-
-    strict_permissions = zope.interface.Attribute(
-        "Require that all configuration files are owned by the current "
-        "user; only needed if your config is somewhere unsafe like /tmp/."
-        "This is a boolean")
-
-    disable_renew_updates = zope.interface.Attribute(
-        "If updates provided by installer enhancements when Certbot is being run"
-        " with \"renew\" verb should be disabled.")
-
-    preferred_chain = zope.interface.Attribute(
-        "If the CA offers multiple certificate chains, prefer the chain whose "
-        "topmost certificate was issued from this Subject Common Name. "
-        "If no match, the default offered chain will be used."
-    )
+class IInstaller(IPlugin):  # pylint: disable=inherit-non-class
+    """Deprecated, use certbot.interfaces.Installer as ABC instead."""
 
 
-class IInstaller(IPlugin):
+class Installer(Plugin):
     """Generic Certbot Installer Interface.
 
     Represents any server that an X509 certificate can be placed.
@@ -283,14 +236,17 @@ class IInstaller(IPlugin):
 
     """
 
-    def get_all_names():  # type: ignore
+    @abstractmethod
+    def get_all_names(self) -> Iterable[str]:
         """Returns all names that may be authenticated.
 
         :rtype: `collections.Iterable` of `str`
 
         """
 
-    def deploy_cert(domain, cert_path, key_path, chain_path, fullchain_path):
+    @abstractmethod
+    def deploy_cert(self, domain: str, cert_path: str, key_path: str,
+                    chain_path: str, fullchain_path: str) -> None:
         """Deploy certificate.
 
         :param str domain: domain to deploy certificate file
@@ -304,7 +260,8 @@ class IInstaller(IPlugin):
 
         """
 
-    def enhance(domain, enhancement, options=None):
+    @abstractmethod
+    def enhance(self, domain: str, enhancement: str, options: Optional[List[str]] = None) -> None:
         """Perform a configuration enhancement.
 
         :param str domain: domain for which to provide enhancement
@@ -320,7 +277,8 @@ class IInstaller(IPlugin):
 
         """
 
-    def supported_enhancements():  # type: ignore
+    @abstractmethod
+    def supported_enhancements(self) -> List[str]:
         """Returns a `collections.Iterable` of supported enhancements.
 
         :returns: supported enhancements which should be a subset of
@@ -329,7 +287,8 @@ class IInstaller(IPlugin):
 
         """
 
-    def save(title=None, temporary=False):
+    @abstractmethod
+    def save(self, title: Optional[str] = None, temporary: bool = False) -> None:
         """Saves all changes to the configuration files.
 
         Both title and temporary are needed because a save may be
@@ -351,14 +310,16 @@ class IInstaller(IPlugin):
 
         """
 
-    def rollback_checkpoints(rollback=1):
+    @abstractmethod
+    def rollback_checkpoints(self, rollback: int = 1) -> None:
         """Revert `rollback` number of configuration checkpoints.
 
         :raises .PluginError: when configuration cannot be fully reverted
 
         """
 
-    def recovery_routine():  # type: ignore
+    @abstractmethod
+    def recovery_routine(self) -> None:
         """Revert configuration to most recent finalized checkpoint.
 
         Remove all changes (temporary and permanent) that have not been
@@ -369,14 +330,16 @@ class IInstaller(IPlugin):
 
         """
 
-    def config_test():  # type: ignore
+    @abstractmethod
+    def config_test(self) -> None:
         """Make sure the configuration is valid.
 
         :raises .MisconfigurationError: when the config is not in a usable state
 
         """
 
-    def restart():  # type: ignore
+    @abstractmethod
+    def restart(self) -> None:
         """Restart or refresh the server content.
 
         :raises .PluginError: when server cannot be restarted
@@ -384,174 +347,19 @@ class IInstaller(IPlugin):
         """
 
 
-class IDisplay(zope.interface.Interface):
-    """Generic display."""
-    # see https://github.com/certbot/certbot/issues/3915
-
-    def notification(message, pause, wrap=True, force_interactive=False):
-        """Displays a string message
-
-        :param str message: Message to display
-        :param bool pause: Whether or not the application should pause for
-            confirmation (if available)
-        :param bool wrap: Whether or not the application should wrap text
-        :param bool force_interactive: True if it's safe to prompt the user
-            because it won't cause any workflow regressions
-
-        """
-
-    def menu(message, choices, ok_label=None,
-             cancel_label=None, help_label=None,
-             default=None, cli_flag=None, force_interactive=False):
-        """Displays a generic menu.
-
-        When not setting force_interactive=True, you must provide a
-        default value.
-
-        :param str message: message to display
-
-        :param choices: choices
-        :type choices: :class:`list` of :func:`tuple` or :class:`str`
-
-        :param str ok_label: label for OK button (UNUSED)
-        :param str cancel_label: label for Cancel button (UNUSED)
-        :param str help_label: label for Help button (UNUSED)
-        :param int default: default (non-interactive) choice from the menu
-        :param str cli_flag: to automate choice from the menu, eg "--keep"
-        :param bool force_interactive: True if it's safe to prompt the user
-            because it won't cause any workflow regressions
-
-        :returns: tuple of (`code`, `index`) where
-            `code` - str display exit code
-            `index` - int index of the user's selection
-
-        :raises errors.MissingCommandlineFlag: if called in non-interactive
-            mode without a default set
-
-        """
-
-    def input(message, default=None, cli_args=None, force_interactive=False):
-        """Accept input from the user.
-
-        When not setting force_interactive=True, you must provide a
-        default value.
-
-        :param str message: message to display to the user
-        :param str default: default (non-interactive) response to prompt
-        :param bool force_interactive: True if it's safe to prompt the user
-            because it won't cause any workflow regressions
-
-        :returns: tuple of (`code`, `input`) where
-            `code` - str display exit code
-            `input` - str of the user's input
-        :rtype: tuple
-
-        :raises errors.MissingCommandlineFlag: if called in non-interactive
-            mode without a default set
-
-        """
-
-    def yesno(message, yes_label="Yes", no_label="No", default=None,
-              cli_args=None, force_interactive=False):
-        """Query the user with a yes/no question.
-
-        Yes and No label must begin with different letters.
-
-        When not setting force_interactive=True, you must provide a
-        default value.
-
-        :param str message: question for the user
-        :param str default: default (non-interactive) choice from the menu
-        :param str cli_flag: to automate choice from the menu, eg "--redirect / --no-redirect"
-        :param bool force_interactive: True if it's safe to prompt the user
-            because it won't cause any workflow regressions
-
-        :returns: True for "Yes", False for "No"
-        :rtype: bool
-
-        :raises errors.MissingCommandlineFlag: if called in non-interactive
-            mode without a default set
-
-        """
-
-    def checklist(message, tags, default=None, cli_args=None, force_interactive=False):
-        """Allow for multiple selections from a menu.
-
-        When not setting force_interactive=True, you must provide a
-        default value.
-
-        :param str message: message to display to the user
-        :param list tags: where each is of type :class:`str` len(tags) > 0
-        :param str default: default (non-interactive) state of the checklist
-        :param str cli_flag: to automate choice from the menu, eg "--domains"
-        :param bool force_interactive: True if it's safe to prompt the user
-            because it won't cause any workflow regressions
-
-        :returns: tuple of the form (code, list_tags) where
-            `code` - int display exit code
-            `list_tags` - list of str tags selected by the user
-        :rtype: tuple
-
-        :raises errors.MissingCommandlineFlag: if called in non-interactive
-            mode without a default set
-
-        """
-
-    def directory_select(self, message, default=None,
-                         cli_flag=None, force_interactive=False):
-        """Display a directory selection screen.
-
-        When not setting force_interactive=True, you must provide a
-        default value.
-
-        :param str message: prompt to give the user
-        :param default: the default value to return, if one exists, when
-            using the NoninteractiveDisplay
-        :param str cli_flag: option used to set this value with the CLI,
-            if one exists, to be included in error messages given by
-            NoninteractiveDisplay
-        :param bool force_interactive: True if it's safe to prompt the user
-            because it won't cause any workflow regressions
-
-        :returns: tuple of the form (`code`, `string`) where
-            `code` - int display exit code
-            `string` - input entered by the user
-
-        """
+class IDisplay(zope.interface.Interface):  # pylint: disable=inherit-non-class
+    """Deprecated, use your own Display implementation instead."""
 
 
-class IReporter(zope.interface.Interface):
-    """Interface to collect and display information to the user."""
-
-    HIGH_PRIORITY = zope.interface.Attribute(
-        "Used to denote high priority messages")
-    MEDIUM_PRIORITY = zope.interface.Attribute(
-        "Used to denote medium priority messages")
-    LOW_PRIORITY = zope.interface.Attribute(
-        "Used to denote low priority messages")
-
-    def add_message(self, msg, priority, on_crash=True):
-        """Adds msg to the list of messages to be printed.
-
-        :param str msg: Message to be displayed to the user.
-
-        :param int priority: One of HIGH_PRIORITY, MEDIUM_PRIORITY, or
-            LOW_PRIORITY.
-
-        :param bool on_crash: Whether or not the message should be printed if
-            the program exits abnormally.
-
-        """
-
-    def print_messages(self):
-        """Prints messages to the user and clears the message queue."""
+class IReporter(zope.interface.Interface):  # pylint: disable=inherit-non-class
+    """Deprecated, use your own Reporter implementation instead."""
 
 
-@six.add_metaclass(abc.ABCMeta)
-class RenewableCert(object):
+class RenewableCert(metaclass=ABCMeta):
     """Interface to a certificate lineage."""
 
-    @abc.abstractproperty
+    @property
+    @abstractmethod
     def cert_path(self):
         """Path to the certificate file.
 
@@ -559,7 +367,8 @@ class RenewableCert(object):
 
         """
 
-    @abc.abstractproperty
+    @property
+    @abstractmethod
     def key_path(self):
         """Path to the private key file.
 
@@ -567,7 +376,8 @@ class RenewableCert(object):
 
         """
 
-    @abc.abstractproperty
+    @property
+    @abstractmethod
     def chain_path(self):
         """Path to the certificate chain file.
 
@@ -575,7 +385,8 @@ class RenewableCert(object):
 
         """
 
-    @abc.abstractproperty
+    @property
+    @abstractmethod
     def fullchain_path(self):
         """Path to the full chain file.
 
@@ -585,7 +396,8 @@ class RenewableCert(object):
 
         """
 
-    @abc.abstractproperty
+    @property
+    @abstractmethod
     def lineagename(self):
         """Name given to the certificate lineage.
 
@@ -593,7 +405,7 @@ class RenewableCert(object):
 
         """
 
-    @abc.abstractmethod
+    @abstractmethod
     def names(self):
         """What are the subject names of this certificate?
 
@@ -613,8 +425,8 @@ class RenewableCert(object):
 # an update during the run or install subcommand, it should do so when
 # :func:`IInstaller.deploy_cert` is called.
 
-@six.add_metaclass(abc.ABCMeta)
-class GenericUpdater(object):
+
+class GenericUpdater(metaclass=ABCMeta):
     """Interface for update types not currently specified by Certbot.
 
     This class allows plugins to perform types of updates that Certbot hasn't
@@ -626,10 +438,10 @@ class GenericUpdater(object):
 
     The plugins implementing this enhancement are responsible of handling
     the saving of configuration checkpoints as well as other calls to
-    interface methods of `interfaces.IInstaller` such as prepare() and restart()
+    interface methods of `interfaces.Installer` such as prepare() and restart()
     """
 
-    @abc.abstractmethod
+    @abstractmethod
     def generic_updates(self, lineage, *args, **kwargs):
         """Perform any update types defined by the installer.
 
@@ -646,8 +458,7 @@ class GenericUpdater(object):
         """
 
 
-@six.add_metaclass(abc.ABCMeta)
-class RenewDeployer(object):
+class RenewDeployer(metaclass=ABCMeta):
     """Interface for update types run when a lineage is renewed
 
     This class allows plugins to perform types of updates that need to run at
@@ -658,12 +469,12 @@ class RenewDeployer(object):
     be called from the installer code.
     """
 
-    @abc.abstractmethod
+    @abstractmethod
     def renew_deploy(self, lineage, *args, **kwargs):
         """Perform updates defined by installer when a certificate has been renewed
 
         If an installer is a subclass of the class containing this method, this
-        function will always be called when a certficate has been renewed by
+        function will always be called when a certificate has been renewed by
         running "certbot renew". For example if a plugin needs to copy a
         certificate over, or change configuration based on the new certificate.
 
@@ -673,3 +484,36 @@ class RenewDeployer(object):
         :type lineage: RenewableCert
 
         """
+
+
+# This class takes a similar approach to the cryptography project to deprecate attributes
+# in public modules. See the _ModuleWithDeprecation class here:
+# https://github.com/pyca/cryptography/blob/91105952739442a74582d3e62b3d2111365b0dc7/src/cryptography/utils.py#L129
+class _ZopeInterfacesDeprecationModule:
+    """
+    Internal class delegating to a module, and displaying warnings when
+    attributes related to Zope interfaces are accessed.
+    """
+    def __init__(self, module):
+        self.__dict__['_module'] = module
+
+    def __getattr__(self, attr):
+        if attr in ('IConfig', 'IPlugin', 'IPluginFactory', 'IAuthenticator',
+                    'IInstaller', 'IDisplay', 'IReporter'):
+            warnings.warn('{0} attribute in certbot.interfaces module is deprecated '
+                          'and will be removed soon.'.format(attr),
+                          DeprecationWarning, stacklevel=2)
+        return getattr(self._module, attr)
+
+    def __setattr__(self, attr, value):  # pragma: no cover
+        setattr(self._module, attr, value)
+
+    def __delattr__(self, attr):  # pragma: no cover
+        delattr(self._module, attr)
+
+    def __dir__(self):  # pragma: no cover
+        return ['_module'] + dir(self._module)
+
+
+# Patching ourselves to warn about Zope interfaces deprecation and planned removal.
+sys.modules[__name__] = cast(ModuleType, _ZopeInterfacesDeprecationModule(sys.modules[__name__]))
