@@ -1,28 +1,23 @@
 """Plugin common functions."""
+from abc import ABCMeta
+from abc import abstractmethod
 import logging
 import re
 import shutil
-import sys
 import tempfile
-import warnings
+from typing import List
 
-import OpenSSL
 import pkg_resources
-import zope.interface
 
-from josepy import util as jose_util
-
-from acme.magic_typing import List  # pylint: disable=unused-import, no-name-in-module
-
-from certbot import achallenges  # pylint: disable=unused-import
-from certbot import constants
+from certbot import achallenges
 from certbot import crypto_util
 from certbot import errors
-from certbot import interfaces
 from certbot import reverter
-from certbot import util
-from certbot.compat import os
+from certbot._internal import constants
 from certbot.compat import filesystem
+from certbot.compat import os
+from certbot.interfaces import Installer as AbstractInstaller
+from certbot.interfaces import Plugin as AbstractPlugin
 from certbot.plugins.storage import PluginStorage
 
 logger = logging.getLogger(__name__)
@@ -37,6 +32,7 @@ def dest_namespace(name):
     """ArgumentParser dest namespace (prefix of all destinations)."""
     return name.replace("-", "_") + "_"
 
+
 private_ips_regex = re.compile(
     r"(^127\.0\.0\.1)|(^10\.)|(^172\.1[6-9]\.)|"
     r"(^172\.2[0-9]\.)|(^172\.3[0-1]\.)|(^192\.168\.)")
@@ -44,24 +40,19 @@ hostname_regex = re.compile(
     r"^(([a-z0-9]|[a-z0-9][a-z0-9\-]*[a-z0-9])\.)*[a-z]+$", re.IGNORECASE)
 
 
-@zope.interface.implementer(interfaces.IPlugin)
-class Plugin(object):
+class Plugin(AbstractPlugin, metaclass=ABCMeta):
     """Generic plugin."""
-    # provider is not inherited, subclasses must define it on their own
-    # @zope.interface.provider(interfaces.IPluginFactory)
 
     def __init__(self, config, name):
+        super().__init__(config, name)
         self.config = config
         self.name = name
 
-    @jose_util.abstractclassmethod
+    @classmethod
+    @abstractmethod
     def add_parser_arguments(cls, add):
         """Add plugin arguments to the CLI argument parser.
 
-        NOTE: If some of your flags interact with others, you can
-        use cli.report_config_interaction to register this to ensure
-        values are correctly saved/overridable during renewal.
-
         :param callable add: Function that proxies calls to
             `argparse.ArgumentParser.add_argument` prepending options
             with unique plugin name prefix.
@@ -72,12 +63,11 @@ class Plugin(object):
     def inject_parser_options(cls, parser, name):
         """Inject parser options.
 
-        See `~.IPlugin.inject_parser_options` for docs.
+        See `~.certbot.interfaces.Plugin.inject_parser_options` for docs.
 
         """
         # dummy function, doesn't check if dest.startswith(self.dest_namespace)
         def add(arg_name_no_prefix, *args, **kwargs):
-            # pylint: disable=missing-docstring
             return parser.add_argument(
                 "--{0}{1}".format(option_namespace(name), arg_name_no_prefix),
                 *args, **kwargs)
@@ -107,15 +97,41 @@ class Plugin(object):
         """Find a configuration value for variable ``var``."""
         return getattr(self.config, self.dest(var))
 
+    def auth_hint(self, failed_achalls: List[achallenges.AnnotatedChallenge]) -> str:
+        """Human-readable string to help the user troubleshoot the authenticator.
 
-class Installer(Plugin):
+        Shown to the user if one or more of the attempted challenges were not a success.
+
+        Should describe, in simple language, what the authenticator tried to do, what went
+        wrong and what the user should try as their "next steps".
+
+        TODO: auth_hint belongs in Authenticator but can't be added until the next major
+        version of Certbot. For now, it lives in .Plugin and auth_handler will only call it
+        on authenticators that subclass .Plugin. For now, inherit from `.Plugin` to implement
+        and/or override the method.
+
+        :param list failed_achalls: List of one or more failed challenges
+                                    (:class:`achallenges.AnnotatedChallenge` subclasses).
+
+        :rtype str:
+        """
+        # This is a fallback hint. Authenticators should implement their own auth_hint that
+        # addresses the specific mechanics of that authenticator.
+        challs = " and ".join(sorted({achall.typ for achall in failed_achalls}))
+        return ("The Certificate Authority couldn't externally verify that the {name} plugin "
+                "completed the required {challs} challenges. Ensure the plugin is configured "
+                "correctly and that the changes it makes are accessible from the internet."
+                .format(name=self.name, challs=challs))
+
+
+class Installer(AbstractInstaller, Plugin, metaclass=ABCMeta):
     """An installer base class with reverter and ssl_dhparam methods defined.
 
     Installer plugins do not have to inherit from this class.
 
     """
     def __init__(self, *args, **kwargs):
-        super(Installer, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.storage = PluginStorage(self.config, self.name)
         self.reverter = reverter.Reverter(self.config)
 
@@ -192,26 +208,6 @@ class Installer(Plugin):
         except errors.ReverterError as err:
             raise errors.PluginError(str(err))
 
-    def view_config_changes(self):
-        """Show all of the configuration changes that have taken place.
-
-        :raises .errors.PluginError: If there is a problem while processing
-            the checkpoints directories.
-
-        """
-        warnings.warn(
-            "The view_config_changes method is no longer part of Certbot's"
-            " plugin interface, has been deprecated, and will be removed in a"
-            " future release.", DeprecationWarning, stacklevel=2)
-        with warnings.catch_warnings():
-            # Don't let the reverter code warn about this function. Calling
-            # this function in the first place is the real problem.
-            warnings.filterwarnings("ignore", ".*view_config_changes", DeprecationWarning)
-            try:
-                self.reverter.view_config_changes()
-            except errors.ReverterError as err:
-                raise errors.PluginError(str(err))
-
     @property
     def ssl_dhparams(self):
         """Full absolute path to ssl_dhparams file."""
@@ -231,7 +227,7 @@ class Installer(Plugin):
             constants.ALL_SSL_DHPARAMS_HASHES)
 
 
-class Addr(object):
+class Addr:
     r"""Represents an virtual host address.
 
     :param str addr: addr part of vhost address
@@ -318,7 +314,7 @@ class Addr(object):
                 # appended to the end
                 append_to_end = True
                 continue
-            elif len(block) > 1:
+            if len(block) > 1:
                 # remove leading zeros
                 block = block.lstrip("0")
             if not append_to_end:
@@ -329,7 +325,7 @@ class Addr(object):
         return result
 
 
-class ChallengePerformer(object):
+class ChallengePerformer:
     """Abstract base for challenge performers.
 
     :ivar configurator: Authenticator and installer plugin
@@ -343,8 +339,8 @@ class ChallengePerformer(object):
 
     def __init__(self, configurator):
         self.configurator = configurator
-        self.achalls = []  # type: List[achallenges.KeyAuthorizationAnnotatedChallenge]
-        self.indices = []  # type: List[int]
+        self.achalls: List[achallenges.KeyAuthorizationAnnotatedChallenge] = []
+        self.indices: List[int] = []
 
     def add_chall(self, achall, idx=None):
         """Store challenge to be performed when perform() is called.
@@ -369,63 +365,6 @@ class ChallengePerformer(object):
         raise NotImplementedError()
 
 
-class TLSSNI01(ChallengePerformer):
-    # pylint: disable=abstract-method
-    """Abstract base for TLS-SNI-01 challenge performers"""
-
-    def __init__(self, configurator):
-        super(TLSSNI01, self).__init__(configurator)
-        self.challenge_conf = os.path.join(
-            configurator.config.config_dir, "le_tls_sni_01_cert_challenge.conf")
-        # self.completed = 0
-
-    def get_cert_path(self, achall):
-        """Returns standardized name for challenge certificate.
-
-        :param .KeyAuthorizationAnnotatedChallenge achall: Annotated
-            tls-sni-01 challenge.
-
-        :returns: certificate file name
-        :rtype: str
-
-        """
-        return os.path.join(self.configurator.config.work_dir,
-                            achall.chall.encode("token") + ".crt")
-
-    def get_key_path(self, achall):
-        """Get standardized path to challenge key."""
-        return os.path.join(self.configurator.config.work_dir,
-                            achall.chall.encode("token") + '.pem')
-
-    def get_z_domain(self, achall):
-        """Returns z_domain (SNI) name for the challenge."""
-        return achall.response(achall.account_key).z_domain.decode("utf-8")
-
-    def _setup_challenge_cert(self, achall, cert_key=None):
-
-        """Generate and write out challenge certificate."""
-        cert_path = self.get_cert_path(achall)
-        key_path = self.get_key_path(achall)
-        # Register the path before you write out the file
-        self.configurator.reverter.register_file_creation(True, key_path)
-        self.configurator.reverter.register_file_creation(True, cert_path)
-
-        response, (cert, key) = achall.response_and_validation(
-            cert_key=cert_key)
-        cert_pem = OpenSSL.crypto.dump_certificate(
-            OpenSSL.crypto.FILETYPE_PEM, cert)
-        key_pem = OpenSSL.crypto.dump_privatekey(
-            OpenSSL.crypto.FILETYPE_PEM, key)
-
-        # Write out challenge cert and key
-        with open(cert_path, "wb") as cert_chall_fd:
-            cert_chall_fd.write(cert_pem)
-        with util.safe_open(key_path, 'wb', chmod=0o400) as key_file:
-            key_file.write(key_pem)
-
-        return response
-
-
 def install_version_controlled_file(dest_path, digest_path, src_path, all_hashes):
     """Copy a file into an active location (likely the system's config dir) if required.
 
@@ -454,9 +393,9 @@ def install_version_controlled_file(dest_path, digest_path, src_path, all_hashes
     active_file_digest = crypto_util.sha256sum(dest_path)
     if active_file_digest == current_hash: # already up to date
         return
-    elif active_file_digest in all_hashes: # safe to update
+    if active_file_digest in all_hashes: # safe to update
         _install_current_file()
-    else: # has been manually modified, not safe to update
+    else:  # has been manually modified, not safe to update
         # did they modify the current version or an old version?
         if os.path.isfile(digest_path):
             with open(digest_path, "r") as f:
@@ -504,34 +443,3 @@ def dir_setup(test_dir, pkg):  # pragma: no cover
         test_configs, os.path.join(temp_dir, test_dir), symlinks=True)
 
     return temp_dir, config_dir, work_dir
-
-
-# This class takes a similar approach to the cryptography project to deprecate attributes
-# in public modules. See the _ModuleWithDeprecation class here:
-# https://github.com/pyca/cryptography/blob/91105952739442a74582d3e62b3d2111365b0dc7/src/cryptography/utils.py#L129
-class _TLSSNI01DeprecationModule(object):
-    """
-    Internal class delegating to a module, and displaying warnings when
-    attributes related to TLS-SNI-01 are accessed.
-    """
-    def __init__(self, module):
-        self.__dict__['_module'] = module
-
-    def __getattr__(self, attr):
-        if attr == 'TLSSNI01':
-            warnings.warn('TLSSNI01 is deprecated and will be removed soon.',
-                          DeprecationWarning, stacklevel=2)
-        return getattr(self._module, attr)
-
-    def __setattr__(self, attr, value):  # pragma: no cover
-        setattr(self._module, attr, value)
-
-    def __delattr__(self, attr):  # pragma: no cover
-        delattr(self._module, attr)
-
-    def __dir__(self):  # pragma: no cover
-        return ['_module'] + dir(self._module)
-
-
-# Patching ourselves to warn about TLS-SNI challenge deprecation and removal.
-sys.modules[__name__] = _TLSSNI01DeprecationModule(sys.modules[__name__])
