@@ -2,15 +2,15 @@
 import logging
 import unittest
 
+import certbot.util
+
 try:
     import mock
 except ImportError:  # pragma: no cover
     from unittest import mock
 import OpenSSL
-import zope.component
 
 from certbot import errors
-from certbot import interfaces
 from certbot import util
 from certbot.compat import filesystem
 from certbot.compat import os
@@ -33,34 +33,32 @@ CERT_ISSUER = test_util.load_vector('cert_intermediate_1.pem')
 CERT_ALT_ISSUER = test_util.load_vector('cert_intermediate_2.pem')
 
 
-class InitSaveKeyTest(test_util.TempDirTestCase):
-    """Tests for certbot.crypto_util.init_save_key."""
+class GenerateKeyTest(test_util.TempDirTestCase):
+    """Tests for certbot.crypto_util.generate_key."""
     def setUp(self):
-        super(InitSaveKeyTest, self).setUp()
+        super().setUp()
 
         self.workdir = os.path.join(self.tempdir, 'workdir')
         filesystem.mkdir(self.workdir, mode=0o700)
 
         logging.disable(logging.CRITICAL)
-        zope.component.provideUtility(
-            mock.Mock(strict_permissions=True), interfaces.IConfig)
 
     def tearDown(self):
-        super(InitSaveKeyTest, self).tearDown()
+        super().tearDown()
 
         logging.disable(logging.NOTSET)
 
     @classmethod
     def _call(cls, key_size, key_dir):
-        from certbot.crypto_util import init_save_key
-        return init_save_key(key_size, key_dir, 'key-certbot.pem')
+        from certbot.crypto_util import generate_key
+        return generate_key(key_size, key_dir, 'key-certbot.pem', strict_permissions=True)
 
     @mock.patch('certbot.crypto_util.make_key')
     def test_success(self, mock_make):
         mock_make.return_value = b'key_pem'
         key = self._call(1024, self.workdir)
         self.assertEqual(key.pem, b'key_pem')
-        self.assertTrue('key-certbot.pem' in key.file)
+        self.assertIn('key-certbot.pem', key.file)
         self.assertTrue(os.path.exists(os.path.join(self.workdir, key.file)))
 
     @mock.patch('certbot.crypto_util.make_key')
@@ -69,27 +67,55 @@ class InitSaveKeyTest(test_util.TempDirTestCase):
         self.assertRaises(ValueError, self._call, 431, self.workdir)
 
 
-class InitSaveCSRTest(test_util.TempDirTestCase):
-    """Tests for certbot.crypto_util.init_save_csr."""
+class InitSaveKey(unittest.TestCase):
+    """Test for certbot.crypto_util.init_save_key."""
+    @mock.patch("certbot.crypto_util.generate_key")
+    @mock.patch("certbot.crypto_util.zope.component")
+    def test_it(self, mock_zope, mock_generate):
+        from certbot.crypto_util import init_save_key
 
-    def setUp(self):
-        super(InitSaveCSRTest, self).setUp()
+        mock_zope.getUtility.return_value = mock.MagicMock(strict_permissions=True)
 
-        zope.component.provideUtility(
-            mock.Mock(strict_permissions=True), interfaces.IConfig)
+        with self.assertWarns(DeprecationWarning):
+            init_save_key(4096, "/some/path")
 
+        mock_generate.assert_called_with(4096, "/some/path", elliptic_curve="secp256r1",
+                                         key_type="rsa", keyname="key-certbot.pem",
+                                         strict_permissions=True)
+
+
+class GenerateCSRTest(test_util.TempDirTestCase):
+    """Tests for certbot.crypto_util.generate_csr."""
     @mock.patch('acme.crypto_util.make_csr')
     @mock.patch('certbot.crypto_util.util.make_or_verify_dir')
     def test_it(self, unused_mock_verify, mock_csr):
-        from certbot.crypto_util import init_save_csr
+        from certbot.crypto_util import generate_csr
 
         mock_csr.return_value = b'csr_pem'
 
-        csr = init_save_csr(
-            mock.Mock(pem='dummy_key'), 'example.com', self.tempdir)
+        csr = generate_csr(
+            mock.Mock(pem='dummy_key'), 'example.com', self.tempdir, strict_permissions=True)
 
         self.assertEqual(csr.data, b'csr_pem')
-        self.assertTrue('csr-certbot.pem' in csr.file)
+        self.assertIn('csr-certbot.pem', csr.file)
+
+
+class InitSaveCsr(unittest.TestCase):
+    """Tests for certbot.crypto_util.init_save_csr."""
+    @mock.patch("certbot.crypto_util.generate_csr")
+    @mock.patch("certbot.crypto_util.zope.component")
+    def test_it(self, mock_zope, mock_generate):
+        from certbot.crypto_util import init_save_csr
+
+        mock_zope.getUtility.return_value = mock.MagicMock(must_staple=True,
+                                                           strict_permissions=True)
+        key = certbot.util.Key(file=None, pem=None)
+
+        with self.assertWarns(DeprecationWarning):
+            init_save_csr(key, {"dummy"}, "/some/path")
+
+        mock_generate.assert_called_with(key, {"dummy"}, "/some/path",
+                                         must_staple=True, strict_permissions=True)
 
 
 class ValidCSRTest(unittest.TestCase):
@@ -251,7 +277,7 @@ class VerifyRenewableCertTest(VerifyCertSetup):
         return verify_renewable_cert(renewable_cert)
 
     def test_verify_renewable_cert(self):
-        self.assertEqual(None, self._call(self.renewable_cert))
+        self.assertIsNone(self._call(self.renewable_cert))
 
     @mock.patch('certbot.crypto_util.verify_renewable_cert_sig', side_effect=errors.Error(""))
     def test_verify_renewable_cert_failure(self, unused_verify_renewable_cert_sign):
@@ -266,14 +292,14 @@ class VerifyRenewableCertSigTest(VerifyCertSetup):
         return verify_renewable_cert_sig(renewable_cert)
 
     def test_cert_sig_match(self):
-        self.assertEqual(None, self._call(self.renewable_cert))
+        self.assertIsNone(self._call(self.renewable_cert))
 
     def test_cert_sig_match_ec(self):
         renewable_cert = mock.MagicMock()
         renewable_cert.cert_path = P256_CERT_PATH
         renewable_cert.chain_path = P256_CERT_PATH
         renewable_cert.key_path = P256_KEY
-        self.assertEqual(None, self._call(renewable_cert))
+        self.assertIsNone(self._call(renewable_cert))
 
     def test_cert_sig_mismatch(self):
         self.bad_renewable_cert.cert_path = test_util.vector_path('cert_512_bad.pem')
@@ -288,7 +314,7 @@ class VerifyFullchainTest(VerifyCertSetup):
         return verify_fullchain(renewable_cert)
 
     def test_fullchain_matches(self):
-        self.assertEqual(None, self._call(self.renewable_cert))
+        self.assertIsNone(self._call(self.renewable_cert))
 
     def test_fullchain_mismatch(self):
         self.assertRaises(errors.Error, self._call, self.bad_renewable_cert)
@@ -308,7 +334,7 @@ class VerifyCertMatchesPrivKeyTest(VerifyCertSetup):
     def test_cert_priv_key_match(self):
         self.renewable_cert.cert = SS_CERT_PATH
         self.renewable_cert.privkey = RSA2048_KEY_PATH
-        self.assertEqual(None, self._call(self.renewable_cert))
+        self.assertIsNone(self._call(self.renewable_cert))
 
     def test_cert_priv_key_mismatch(self):
         self.bad_renewable_cert.privkey = RSA256_KEY_PATH
@@ -381,6 +407,37 @@ class GetNamesFromCertTest(unittest.TestCase):
         self.assertRaises(OpenSSL.crypto.Error, self._call, "hello there")
 
 
+class GetNamesFromReqTest(unittest.TestCase):
+    """Tests for certbot.crypto_util.get_names_from_req."""
+
+    @classmethod
+    def _call(cls, *args, **kwargs):
+        from certbot.crypto_util import get_names_from_req
+        return get_names_from_req(*args, **kwargs)
+
+    def test_nonames(self):
+        self.assertEqual(
+            [],
+            self._call(test_util.load_vector('csr-nonames_512.pem')))
+
+    def test_nosans(self):
+        self.assertEqual(
+            ['example.com'],
+            self._call(test_util.load_vector('csr-nosans_512.pem')))
+
+    def test_sans(self):
+        self.assertEqual(
+            ['example.com', 'example.org', 'example.net', 'example.info',
+             'subdomain.example.com', 'other.subdomain.example.com'],
+            self._call(test_util.load_vector('csr-6sans_512.pem')))
+
+    def test_der(self):
+        from OpenSSL.crypto import FILETYPE_ASN1
+        self.assertEqual(
+            ['Example.com'],
+            self._call(test_util.load_vector('csr_512.der'), typ=FILETYPE_ASN1))
+
+
 class CertLoaderTest(unittest.TestCase):
     """Tests for certbot.crypto_util.pyopenssl_load_certificate"""
 
@@ -493,13 +550,13 @@ class FindChainWithIssuerTest(unittest.TestCase):
         self.assertEqual(matched, fullchains[0])
         mock_info.assert_not_called()
 
-    @mock.patch('certbot.crypto_util.logger.info')
-    def test_warning_on_no_match(self, mock_info):
+    @mock.patch('certbot.crypto_util.logger.warning')
+    def test_warning_on_no_match(self, mock_warning):
         fullchains = self._all_fullchains()
         matched = self._call(fullchains, "non-existent issuer",
                              warn_on_no_match=True)
         self.assertEqual(matched, fullchains[0])
-        mock_info.assert_called_once_with("Certbot has been configured to prefer "
+        mock_warning.assert_called_once_with("Certbot has been configured to prefer "
             "certificate chains with issuer '%s', but no chain from the CA matched "
             "this issuer. Using the default certificate chain instead.",
             "non-existent issuer")
