@@ -1,12 +1,12 @@
 """Tests for certbot._internal.plugins.manual"""
 import sys
+import textwrap
 import unittest
 
 try:
     import mock
 except ImportError: # pragma: no cover
     from unittest import mock
-import six
 
 from acme import challenges
 from certbot import errors
@@ -20,7 +20,11 @@ class AuthenticatorTest(test_util.TempDirTestCase):
     """Tests for certbot._internal.plugins.manual.Authenticator."""
 
     def setUp(self):
-        super(AuthenticatorTest, self).setUp()
+        super().setUp()
+        get_display_patch = test_util.patch_display_util()
+        self.mock_get_display = get_display_patch.start()
+        self.addCleanup(get_display_patch.stop)
+
         self.http_achall = acme_util.HTTP01_A
         self.dns_achall = acme_util.DNS01_A
         self.dns_achall_2 = acme_util.DNS01_A_2
@@ -53,7 +57,7 @@ class AuthenticatorTest(test_util.TempDirTestCase):
         self.assertRaises(errors.HookCommandNotFound, self.auth.prepare)
 
     def test_more_info(self):
-        self.assertTrue(isinstance(self.auth.more_info(), six.string_types))
+        self.assertIsInstance(self.auth.more_info(), str)
 
     def test_get_chall_pref(self):
         self.assertEqual(self.auth.get_chall_pref('example.org'),
@@ -61,7 +65,7 @@ class AuthenticatorTest(test_util.TempDirTestCase):
 
     def test_script_perform(self):
         self.config.manual_auth_hook = (
-            '{0} -c "from __future__ import print_function;'
+            '{0} -c "'
             'from certbot.compat import os;'
             'print(os.environ.get(\'CERTBOT_DOMAIN\'));'
             'print(os.environ.get(\'CERTBOT_TOKEN\', \'notoken\'));'
@@ -90,16 +94,22 @@ class AuthenticatorTest(test_util.TempDirTestCase):
             self.auth.env[self.http_achall]['CERTBOT_AUTH_OUTPUT'],
             http_expected)
 
-    @test_util.patch_get_utility()
-    def test_manual_perform(self, mock_get_utility):
+        # Successful hook output should be sent to notify
+        self.assertEqual(self.mock_get_display().notification.call_count, len(self.achalls))
+        for i, (args, _) in enumerate(self.mock_get_display().notification.call_args_list):
+            needle = textwrap.indent(self.auth.env[self.achalls[i]]['CERTBOT_AUTH_OUTPUT'], ' ')
+            self.assertIn(needle, args[0])
+
+    def test_manual_perform(self):
         self.assertEqual(
             self.auth.perform(self.achalls),
             [achall.response(achall.account_key) for achall in self.achalls])
-        for i, (args, kwargs) in enumerate(mock_get_utility().notification.call_args_list):
+
+        self.assertEqual(self.mock_get_display().notification.call_count, len(self.achalls))
+        for i, (args, kwargs) in enumerate(self.mock_get_display().notification.call_args_list):
             achall = self.achalls[i]
-            self.assertTrue(
-                achall.validation(achall.account_key) in args[0])
-            self.assertFalse(kwargs['wrap'])
+            self.assertIn(achall.validation(achall.account_key), args[0])
+            self.assertIs(kwargs['wrap'], False)
 
     def test_cleanup(self):
         self.config.manual_auth_hook = ('{0} -c "import sys; sys.stdout.write(\'foo\')"'
@@ -120,7 +130,36 @@ class AuthenticatorTest(test_util.TempDirTestCase):
                     os.environ['CERTBOT_TOKEN'],
                     achall.chall.encode('token'))
             else:
-                self.assertFalse('CERTBOT_TOKEN' in os.environ)
+                self.assertNotIn('CERTBOT_TOKEN', os.environ)
+
+    def test_auth_hint_hook(self):
+        self.config.manual_auth_hook = '/bin/true'
+        self.assertEqual(
+            self.auth.auth_hint([acme_util.DNS01_A, acme_util.HTTP01_A]),
+            'The Certificate Authority failed to verify the DNS TXT records and challenge '
+            'files created by the --manual-auth-hook. Ensure that this hook is functioning '
+            'correctly and that it waits a sufficient duration of time for DNS propagation. '
+            'Refer to "certbot --help manual" and the Certbot User Guide.'
+        )
+        self.assertEqual(
+            self.auth.auth_hint([acme_util.HTTP01_A]),
+            'The Certificate Authority failed to verify the challenge files created by the '
+            '--manual-auth-hook. Ensure that this hook is functioning correctly. Refer to '
+            '"certbot --help manual" and the Certbot User Guide.'
+        )
+
+    def test_auth_hint_no_hook(self):
+        self.assertEqual(
+            self.auth.auth_hint([acme_util.DNS01_A, acme_util.HTTP01_A]),
+            'The Certificate Authority failed to verify the manually created DNS TXT records '
+            'and challenge files. Ensure that you created these in the correct location, or '
+            'try waiting longer for DNS propagation on the next attempt.'
+        )
+        self.assertEqual(
+            self.auth.auth_hint([acme_util.HTTP01_A, acme_util.HTTP01_A, acme_util.HTTP01_A]),
+            'The Certificate Authority failed to verify the manually created challenge files. '
+            'Ensure that you created these in the correct location.'
+        )
 
 
 if __name__ == '__main__':
