@@ -11,7 +11,6 @@ try:
 except ImportError: # pragma: no cover
     from unittest import mock
 import pytz
-import six
 
 import certbot
 from certbot import errors
@@ -77,6 +76,17 @@ class RelevantValuesTest(unittest.TestCase):
 
         self.assertEqual(self._call(self.values), expected_relevant_values)
 
+    @mock.patch("certbot._internal.cli.set_by_cli")
+    def test_deprecated_item(self, unused_mock_set_by_cli):
+        # deprecated items should never be relevant to store
+        expected_relevant_values = self.values.copy()
+        self.values["manual_public_ip_logging_ok"] = None
+        self.assertEqual(self._call(self.values), expected_relevant_values)
+        self.values["manual_public_ip_logging_ok"] = True
+        self.assertEqual(self._call(self.values), expected_relevant_values)
+        self.values["manual_public_ip_logging_ok"] = False
+        self.assertEqual(self._call(self.values), expected_relevant_values)
+
 
 class BaseRenewableCertTest(test_util.ConfigTestCase):
     """Base class for setting up Renewable Cert tests.
@@ -89,7 +99,7 @@ class BaseRenewableCertTest(test_util.ConfigTestCase):
     def setUp(self):
         from certbot._internal import storage
 
-        super(BaseRenewableCertTest, self).setUp()
+        super().setUp()
 
         # TODO: maybe provide NamespaceConfig.make_dirs?
         # TODO: main() should create those dirs, c.f. #902
@@ -185,11 +195,11 @@ class RenewableCertTests(BaseRenewableCertTest):
         from certbot._internal import storage
 
         self._write_out_ex_kinds()
-        self.assertTrue("version" not in self.config_file)
+        self.assertNotIn("version", self.config_file)
 
         with mock.patch("certbot._internal.storage.logger") as mock_logger:
             storage.RenewableCert(self.config_file.filename, self.config)
-        self.assertFalse(mock_logger.warning.called)
+        self.assertIs(mock_logger.warning.called, False)
 
     def test_renewal_newer_version(self):
         from certbot._internal import storage
@@ -201,7 +211,7 @@ class RenewableCertTests(BaseRenewableCertTest):
         with mock.patch("certbot._internal.storage.logger") as mock_logger:
             storage.RenewableCert(self.config_file.filename, self.config)
         self.assertTrue(mock_logger.info.called)
-        self.assertTrue("version" in mock_logger.info.call_args[0][0])
+        self.assertIn("version", mock_logger.info.call_args[0][0])
 
     def test_consistent(self):
         # pylint: disable=protected-access
@@ -272,10 +282,10 @@ class RenewableCertTests(BaseRenewableCertTest):
         self.assertEqual(self.test_rc.current_version("cert"), 10)
 
     def test_no_current_version(self):
-        self.assertEqual(self.test_rc.current_version("cert"), None)
+        self.assertIsNone(self.test_rc.current_version("cert"))
 
     def test_latest_and_next_versions(self):
-        for ver in six.moves.range(1, 6):
+        for ver in range(1, 6):
             for kind in ALL_FOUR:
                 self._write_out_kind(kind, ver)
         self.assertEqual(self.test_rc.latest_common_version(), 5)
@@ -304,18 +314,18 @@ class RenewableCertTests(BaseRenewableCertTest):
         self.test_rc.latest_common_version = mock.Mock()
 
         mock_has_pending.return_value = False
-        self.assertEqual(self.test_rc.ensure_deployed(), True)
+        self.assertIs(self.test_rc.ensure_deployed(), True)
         self.assertEqual(mock_update.call_count, 0)
         self.assertEqual(mock_logger.warning.call_count, 0)
 
         mock_has_pending.return_value = True
-        self.assertEqual(self.test_rc.ensure_deployed(), False)
+        self.assertIs(self.test_rc.ensure_deployed(), False)
         self.assertEqual(mock_update.call_count, 1)
         self.assertEqual(mock_logger.warning.call_count, 1)
 
 
     def test_update_link_to(self):
-        for ver in six.moves.range(1, 6):
+        for ver in range(1, 6):
             for kind in ALL_FOUR:
                 self._write_out_kind(kind, ver)
                 self.assertEqual(ver, self.test_rc.current_version(kind))
@@ -330,7 +340,7 @@ class RenewableCertTests(BaseRenewableCertTest):
         self.test_rc._update_link_to("chain", 3000)
         # However, current_version doesn't allow querying the resulting
         # version (because it's a broken link).
-        self.assertEqual(os.path.basename(os.readlink(self.test_rc.chain)),
+        self.assertEqual(os.path.basename(filesystem.readlink(self.test_rc.chain)),
                          "chain3000.pem")
 
     def test_version(self):
@@ -342,12 +352,12 @@ class RenewableCertTests(BaseRenewableCertTest):
                          os.path.basename(self.test_rc.version("cert", 8)))
 
     def test_update_all_links_to_success(self):
-        for ver in six.moves.range(1, 6):
+        for ver in range(1, 6):
             for kind in ALL_FOUR:
                 self._write_out_kind(kind, ver)
                 self.assertEqual(ver, self.test_rc.current_version(kind))
         self.assertEqual(self.test_rc.latest_common_version(), 5)
-        for ver in six.moves.range(1, 6):
+        for ver in range(1, 6):
             self.test_rc.update_all_links_to(ver)
             for kind in ALL_FOUR:
                 self.assertEqual(ver, self.test_rc.current_version(kind))
@@ -385,11 +395,11 @@ class RenewableCertTests(BaseRenewableCertTest):
             self.assertEqual(self.test_rc.current_version(kind), 11)
 
     def test_has_pending_deployment(self):
-        for ver in six.moves.range(1, 6):
+        for ver in range(1, 6):
             for kind in ALL_FOUR:
                 self._write_out_kind(kind, ver)
                 self.assertEqual(ver, self.test_rc.current_version(kind))
-        for ver in six.moves.range(1, 6):
+        for ver in range(1, 6):
             self.test_rc.update_all_links_to(ver)
             for kind in ALL_FOUR:
                 self.assertEqual(ver, self.test_rc.current_version(kind))
@@ -487,7 +497,7 @@ class RenewableCertTests(BaseRenewableCertTest):
         # (to avoid instantiating parser)
         mock_rv.side_effect = lambda x: x
 
-        for ver in six.moves.range(1, 6):
+        for ver in range(1, 6):
             for kind in ALL_FOUR:
                 self._write_out_kind(kind, ver)
         self.test_rc.update_all_links_to(3)
@@ -514,11 +524,11 @@ class RenewableCertTests(BaseRenewableCertTest):
         # privkey.
         for i in (6, 7, 8):
             self.assertTrue(os.path.islink(self.test_rc.version("privkey", i)))
-            self.assertEqual("privkey3.pem", os.path.basename(os.readlink(
+            self.assertEqual("privkey3.pem", os.path.basename(filesystem.readlink(
                 self.test_rc.version("privkey", i))))
 
         for kind in ALL_FOUR:
-            self.assertEqual(self.test_rc.available_versions(kind), list(six.moves.range(1, 9)))
+            self.assertEqual(self.test_rc.available_versions(kind), list(range(1, 9)))
             self.assertEqual(self.test_rc.current_version(kind), 3)
         # Test updating from latest version rather than old version
         self.test_rc.update_all_links_to(8)
@@ -527,7 +537,7 @@ class RenewableCertTests(BaseRenewableCertTest):
                                            b'attempt', self.config))
         for kind in ALL_FOUR:
             self.assertEqual(self.test_rc.available_versions(kind),
-                             list(six.moves.range(1, 10)))
+                             list(range(1, 10)))
             self.assertEqual(self.test_rc.current_version(kind), 8)
         with open(self.test_rc.version("fullchain", 9)) as f:
             self.assertEqual(f.read(), "last" + "attempt")
@@ -576,7 +586,7 @@ class RenewableCertTests(BaseRenewableCertTest):
             self._write_out_kind(kind, 1)
         self.test_rc.update_all_links_to(1)
         self.test_rc.save_successor(1, b"newcert", None, b"new chain", self.config)
-        self.assertFalse(mock_ownership.called)
+        self.assertIs(mock_ownership.called, False)
         self.test_rc.save_successor(2, b"newcert", b"new_privkey", b"new chain", self.config)
         self.assertTrue(mock_ownership.called)
 
@@ -755,18 +765,25 @@ class RenewableCertTests(BaseRenewableCertTest):
             self.assertEqual(storage.add_time_interval(base_time, interval),
                              excepted)
 
+    def test_server(self):
+        self.test_rc.configuration["renewalparams"] = {}
+        self.assertIsNone(self.test_rc.server)
+        rp = self.test_rc.configuration["renewalparams"]
+        rp["server"] = "https://acme.example/dir"
+        self.assertEqual(self.test_rc.server, "https://acme.example/dir")
+
     def test_is_test_cert(self):
         self.test_rc.configuration["renewalparams"] = {}
         rp = self.test_rc.configuration["renewalparams"]
-        self.assertEqual(self.test_rc.is_test_cert, False)
+        self.assertIs(self.test_rc.is_test_cert, False)
         rp["server"] = "https://acme-staging-v02.api.letsencrypt.org/directory"
-        self.assertEqual(self.test_rc.is_test_cert, True)
+        self.assertIs(self.test_rc.is_test_cert, True)
         rp["server"] = "https://staging.someotherca.com/directory"
-        self.assertEqual(self.test_rc.is_test_cert, True)
+        self.assertIs(self.test_rc.is_test_cert, True)
         rp["server"] = "https://acme-v01.api.letsencrypt.org/directory"
-        self.assertEqual(self.test_rc.is_test_cert, False)
+        self.assertIs(self.test_rc.is_test_cert, False)
         rp["server"] = "https://acme-v02.api.letsencrypt.org/directory"
-        self.assertEqual(self.test_rc.is_test_cert, False)
+        self.assertIs(self.test_rc.is_test_cert, False)
 
     def test_missing_cert(self):
         from certbot._internal import storage
@@ -800,13 +817,13 @@ class RenewableCertTests(BaseRenewableCertTest):
         with open(temp2, "r") as f:
             content = f.read()
         # useful value was updated
-        self.assertTrue("useful = new_value" in content)
+        self.assertIn("useful = new_value", content)
         # associated comment was preserved
-        self.assertTrue("A useful value" in content)
+        self.assertIn("A useful value", content)
         # useless value was deleted
-        self.assertTrue("useless" not in content)
+        self.assertNotIn("useless", content)
         # check version was stored
-        self.assertTrue("version = {0}".format(certbot.__version__) in content)
+        self.assertIn("version = {0}".format(certbot.__version__), content)
         # ensure permissions are copied
         self.assertEqual(stat.S_IMODE(os.lstat(temp).st_mode),
                          stat.S_IMODE(os.lstat(temp2).st_mode))
@@ -829,7 +846,7 @@ class RenewableCertTests(BaseRenewableCertTest):
 class DeleteFilesTest(BaseRenewableCertTest):
     """Tests for certbot._internal.storage.delete_files"""
     def setUp(self):
-        super(DeleteFilesTest, self).setUp()
+        super().setUp()
 
         for kind in ALL_FOUR:
             kind_path = os.path.join(self.config.config_dir, "live", "example.org",
@@ -919,19 +936,19 @@ class DeleteFilesTest(BaseRenewableCertTest):
 class CertPathForCertNameTest(BaseRenewableCertTest):
     """Test for certbot._internal.storage.cert_path_for_cert_name"""
     def setUp(self):
-        super(CertPathForCertNameTest, self).setUp()
+        super().setUp()
         self.config_file.write()
         self._write_out_ex_kinds()
         self.fullchain = os.path.join(self.config.config_dir, 'live', 'example.org',
                 'fullchain.pem')
-        self.config.cert_path = (self.fullchain, '')
+        self.config.cert_path = self.fullchain
 
     def _call(self, cli_config, certname):
         from certbot._internal.storage import cert_path_for_cert_name
         return cert_path_for_cert_name(cli_config, certname)
 
     def test_simple_cert_name(self):
-        self.assertEqual(self._call(self.config, 'example.org'), (self.fullchain, 'fullchain'))
+        self.assertEqual(self._call(self.config, 'example.org'), self.fullchain)
 
     def test_no_such_cert_name(self):
         self.assertRaises(errors.CertStorageError, self._call, self.config, 'fake-example.org')
