@@ -1,21 +1,22 @@
 """Tests for certbot.util."""
 import argparse
 import errno
+from importlib import reload as reload_module
+import io
 import sys
 import unittest
 
-try:
-    import mock
-except ImportError: # pragma: no cover
-    from unittest import mock
-import six
-from six.moves import reload_module  # pylint: disable=import-error
-
 from certbot import errors
 from certbot.compat import filesystem
 from certbot.compat import os
 import certbot.tests.util as test_util
 
+try:
+    import mock
+except ImportError: # pragma: no cover
+    from unittest import mock
+
+
 
 class EnvNoSnapForExternalCallsTest(unittest.TestCase):
     """Tests for certbot.util.env_no_snap_for_external_calls."""
@@ -58,26 +59,26 @@ class RunScriptTest(unittest.TestCase):
         from certbot.util import run_script
         return run_script(params)
 
-    @mock.patch("certbot.util.subprocess.Popen")
-    def test_default(self, mock_popen):
+    @mock.patch("certbot.util.subprocess.run")
+    def test_default(self, mock_run):
         """These will be changed soon enough with reload."""
-        mock_popen().returncode = 0
-        mock_popen().communicate.return_value = ("stdout", "stderr")
+        mock_run().returncode = 0
+        mock_run().stdout = "stdout"
+        mock_run().stderr = "stderr"
 
         out, err = self._call(["test"])
         self.assertEqual(out, "stdout")
         self.assertEqual(err, "stderr")
 
-    @mock.patch("certbot.util.subprocess.Popen")
-    def test_bad_process(self, mock_popen):
-        mock_popen.side_effect = OSError
+    @mock.patch("certbot.util.subprocess.run")
+    def test_bad_process(self, mock_run):
+        mock_run.side_effect = OSError
 
         self.assertRaises(errors.SubprocessError, self._call, ["test"])
 
-    @mock.patch("certbot.util.subprocess.Popen")
-    def test_failure(self, mock_popen):
-        mock_popen().communicate.return_value = ("", "")
-        mock_popen().returncode = 1
+    @mock.patch("certbot.util.subprocess.run")
+    def test_failure(self, mock_run):
+        mock_run().returncode = 1
 
         self.assertRaises(errors.SubprocessError, self._call, ["test"])
 
@@ -107,7 +108,7 @@ class LockDirUntilExit(test_util.TempDirTestCase):
         return lock_dir_until_exit(*args, **kwargs)
 
     def setUp(self):
-        super(LockDirUntilExit, self).setUp()
+        super().setUp()
         # reset global state from other tests
         import certbot.util
         reload_module(certbot.util)
@@ -163,7 +164,7 @@ class MakeOrVerifyDirTest(test_util.TempDirTestCase):
     """
 
     def setUp(self):
-        super(MakeOrVerifyDirTest, self).setUp()
+        super().setUp()
 
         self.path = os.path.join(self.tempdir, "foo")
         filesystem.mkdir(self.path, 0o600)
@@ -195,7 +196,7 @@ class UniqueFileTest(test_util.TempDirTestCase):
     """Tests for certbot.util.unique_file."""
 
     def setUp(self):
-        super(UniqueFileTest, self).setUp()
+        super().setUp()
 
         self.default_name = os.path.join(self.tempdir, "foo.txt")
 
@@ -259,18 +260,18 @@ class UniqueLineageNameTest(test_util.TempDirTestCase):
 
     def test_basic(self):
         f, path = self._call("wow")
-        self.assertTrue(isinstance(f, file_type))
+        self.assertIsInstance(f, file_type)
         self.assertEqual(os.path.join(self.tempdir, "wow.conf"), path)
         f.close()
 
     def test_multiple(self):
         items = []
-        for _ in six.moves.range(10):
+        for _ in range(10):
             items.append(self._call("wow"))
         f, name = items[-1]
-        self.assertTrue(isinstance(f, file_type))
-        self.assertTrue(isinstance(name, six.string_types))
-        self.assertTrue("wow-0009.conf" in name)
+        self.assertIsInstance(f, file_type)
+        self.assertIsInstance(name, str)
+        self.assertIn("wow-0009.conf", name)
         for f, _ in items:
             f.close()
 
@@ -283,7 +284,7 @@ class SafelyRemoveTest(test_util.TempDirTestCase):
     """Tests for certbot.util.safely_remove."""
 
     def setUp(self):
-        super(SafelyRemoveTest, self).setUp()
+        super().setUp()
 
         self.path = os.path.join(self.tempdir, "foo")
 
@@ -345,29 +346,29 @@ class AddDeprecatedArgumentTest(unittest.TestCase):
 
     def test_warning_no_arg(self):
         self._call("--old-option", 0)
-        with mock.patch("certbot.util.logger.warning") as mock_warn:
+        with mock.patch("warnings.warn") as mock_warn:
             self.parser.parse_args(["--old-option"])
         self.assertEqual(mock_warn.call_count, 1)
-        self.assertTrue("is deprecated" in mock_warn.call_args[0][0])
-        self.assertEqual("--old-option", mock_warn.call_args[0][1])
+        self.assertIn("is deprecated", mock_warn.call_args[0][0])
+        self.assertIn("--old-option", mock_warn.call_args[0][0])
 
     def test_warning_with_arg(self):
         self._call("--old-option", 1)
-        with mock.patch("certbot.util.logger.warning") as mock_warn:
+        with mock.patch("warnings.warn") as mock_warn:
             self.parser.parse_args(["--old-option", "42"])
         self.assertEqual(mock_warn.call_count, 1)
-        self.assertTrue("is deprecated" in mock_warn.call_args[0][0])
-        self.assertEqual("--old-option", mock_warn.call_args[0][1])
+        self.assertIn("is deprecated", mock_warn.call_args[0][0])
+        self.assertIn("--old-option", mock_warn.call_args[0][0])
 
     def test_help(self):
         self._call("--old-option", 2)
-        stdout = six.StringIO()
+        stdout = io.StringIO()
         with mock.patch("sys.stdout", new=stdout):
             try:
                 self.parser.parse_args(["-h"])
             except SystemExit:
                 pass
-        self.assertTrue("--old-option" not in stdout.getvalue())
+        self.assertNotIn("--old-option", stdout.getvalue())
 
     def test_set_constant(self):
         """Test when ACTION_TYPES_THAT_DONT_NEED_A_VALUE is a set.
@@ -518,7 +519,7 @@ class OsInfoTest(unittest.TestCase):
         m_distro.like.return_value = "first debian third"
         id_likes = cbutil.get_systemd_os_like()
         self.assertEqual(len(id_likes), 3)
-        self.assertTrue("debian" in id_likes)
+        self.assertIn("debian", id_likes)
 
     @mock.patch("certbot.util.distro")
     @unittest.skipUnless(sys.platform.startswith("linux"), "requires Linux")
@@ -526,13 +527,13 @@ class OsInfoTest(unittest.TestCase):
         import certbot.util as cbutil
         with mock.patch('platform.system_alias',
                         return_value=('linux', '42', '42')):
-            m_distro.name.return_value = ""
-            m_distro.linux_distribution.return_value = ("something", "1.0", "codename")
-            cbutil.get_python_os_info(pretty=True)
+            m_distro.version.return_value = "1.0"
+            # empty value on first call for fallback to "get_python_os_info" in get_os_info_ua
+            m_distro.name.side_effect = ["", "something", "something"]
             self.assertEqual(cbutil.get_os_info_ua(),
                             " ".join(cbutil.get_python_os_info(pretty=True)))
 
-        m_distro.name.return_value = "whatever"
+        m_distro.name.side_effect = ["whatever"]
         self.assertEqual(cbutil.get_os_info_ua(), "whatever")
 
     @mock.patch("certbot.util.distro")
@@ -540,11 +541,13 @@ class OsInfoTest(unittest.TestCase):
     def test_get_os_info(self, m_distro):
         import certbot.util as cbutil
         with mock.patch("platform.system") as mock_platform:
-            m_distro.linux_distribution.return_value = ("name", "version", 'x')
+            m_distro.id.return_value = "name"
+            m_distro.version.return_value = "version"
             mock_platform.return_value = "linux"
             self.assertEqual(cbutil.get_os_info(), ("name", "version"))
 
-            m_distro.linux_distribution.return_value = ("something", "else")
+            m_distro.id.return_value = "something"
+            m_distro.version.return_value = "else"
             self.assertEqual(cbutil.get_os_info(), ("something", "else"))
 
     def test_non_systemd_os_info(self):
@@ -556,12 +559,8 @@ class OsInfoTest(unittest.TestCase):
 
             with mock.patch('platform.system_alias',
                             return_value=('darwin', '', '')):
-                with mock.patch("subprocess.Popen") as popen_mock:
-                    comm_mock = mock.Mock()
-                    comm_attrs = {'communicate.return_value':
-                                ('42.42.42', 'error')}
-                    comm_mock.configure_mock(**comm_attrs)
-                    popen_mock.return_value = comm_mock
+                with mock.patch("subprocess.run") as run_mock:
+                    run_mock().stdout = '42.42.42'
                     self.assertEqual(cbutil.get_python_os_info()[0], 'darwin')
                     self.assertEqual(cbutil.get_python_os_info()[1], '42.42.42')
 
@@ -580,14 +579,16 @@ class OsInfoTest(unittest.TestCase):
     @unittest.skipUnless(sys.platform.startswith("linux"), "requires Linux")
     def test_python_os_info_notfound(self, m_distro):
         import certbot.util as cbutil
-        m_distro.linux_distribution.return_value = ('', '', '')
+        m_distro.id.return_value = ""
+        m_distro.version.return_value = ""
         self.assertEqual(cbutil.get_python_os_info()[0], "linux")
 
     @mock.patch("certbot.util.distro")
     @unittest.skipUnless(sys.platform.startswith("linux"), "requires Linux")
     def test_python_os_info_custom(self, m_distro):
         import certbot.util as cbutil
-        m_distro.linux_distribution.return_value = ('testdist', '42', '')
+        m_distro.id.return_value = "testdist"
+        m_distro.version.return_value = "42"
         self.assertEqual(cbutil.get_python_os_info(), ("testdist", "42"))
 
 
@@ -609,7 +610,7 @@ class AtexitRegisterTest(unittest.TestCase):
 
     def test_not_called(self):
         self._test_common(initial_pid=-1)
-        self.assertFalse(self.func.called)
+        self.assertIs(self.func.called, False)
 
     def _test_common(self, initial_pid):
         with mock.patch('certbot.util._INITIAL_PID', initial_pid):
